# subete
 
The plan for this repo is to extract the repo traversal utilities
from the sample-programs-docs-generator. I really like this as 
a way of providing a Python library which interfaces with the
Sample Programs repo. I can already see this being useful for
our own internal documentation but also useful for anyone who
just wants to explore code in a bunch of different languages. 
